@@ -20,31 +20,11 @@
 #ifndef QTEST_ARORA_H
 #define QTEST_ARORA_H
 
-#include <QtTest/QTest>
-#include "browserapplication.h"
+#include <qtest.h>
 
-#ifndef QTRY_COMPARE
+#include <browserapplication.h>
 
-#define __TRY_TIMEOUT__ 5000
-#define __TRY_STEP__    50
-
-#define __QTRY(__expression__, __functionToCall__) \
-    do { \
-        int __i = 0; \
-        while (!(__expression__) &&  __i < __TRY_TIMEOUT__) { \
-            QTest::qWait(__TRY_STEP__); \
-            __i += __TRY_STEP__; \
-        } \
-        __functionToCall__; \
-    } while(0)
-
-#define QTRY_COMPARE(__expression__, __expected__) \
-    __QTRY((__expression__ == __expected__), QCOMPARE(__expression__, __expected__));
-
-#define QTRY_VERIFY(__expression__) \
-    __QTRY(__expression__, QVERIFY(__expression__));
-
-#endif // QTRY_COMPARE
+#include "qtry.h"
 
 #undef QTEST_MAIN
 
