@@ -27,6 +27,10 @@
 #include <qtextedit.h>
 #include <qtextstream.h>
 
+#if QT_VERSION >= 0x040600 || defined(WEBKIT_TRUNK)
+#include <qwebkitversion.h>
+#endif
+
 AboutDialog::AboutDialog(QWidget *parent)
     : QDialog(parent)
 {
@@ -35,6 +39,11 @@ AboutDialog::AboutDialog(QWidget *parent)
     logo->setPixmap(qApp->windowIcon().pixmap(128, 128));
     name->setText(qApp->applicationName());
     version->setText(qApp->applicationVersion());
+#if QT_VERSION >= 0x040600 || defined(WEBKIT_TRUNK)
+    webkitVersion->setText(tr("WebKit version: %1").arg(qWebKitVersion()));
+#else
+    webkitVersion->hide();
+#endif
     connect(authorsButton, SIGNAL(clicked()),
             this, SLOT(authorsButtonClicked()));
     connect(licenseButton, SIGNAL(clicked()),
@@ -54,7 +63,9 @@ void AboutDialog::displayFile(const QString &fileName, const QString &title)
     if (!file.open(QIODevice::ReadOnly))
         return;
 
-    QString text = QTextStream(&file).readAll();
+    QTextStream stream(&file);
+    stream.setCodec("UTF-8");
+    QString text = stream.readAll();
     // this is done to force the content of the text editor to be LTR, and monospaced.
     textEdit.setHtml(QString(QLatin1String("<pre>%1</pre>")).arg(text));
 
