@@ -146,5 +146,8 @@ ModelMenu *BookmarksToolBar::createMenu()
     BookmarksMenu *menu = new BookmarksMenu(this);
     connect(menu, SIGNAL(openUrl(const QUrl&, const QString&)),
             this, SIGNAL(openUrl(const QUrl&, const QString&)));
+    connect(menu, SIGNAL(openUrl(const QUrl&, TabWidget::OpenUrlIn, const QString &)),
+            this, SIGNAL(openUrl(const QUrl&, TabWidget::OpenUrlIn, const QString &)));
     return menu;
 }
+
