@@ -250,6 +250,8 @@ bool HistoryCompleter::eventFilter(QObject *obj, QEvent *event)
             if (!QCompleter::eventFilter(obj, newEvent))
                 obj->event(newEvent);
             return true;
+        } else if (keyEvent->key() == Qt::Key_Escape) {
+            popup()->hide();
         }
     }
     return QCompleter::eventFilter(obj, event);
