@@ -54,7 +54,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>About %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Om %1</translation>
     </message>
     <message utf8="true">
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
@@ -62,7 +62,15 @@ p, li { white-space: pre-wrap; }
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Opphavsrett © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <source>WebKit version: %1</source>
+        <translation>WebKit versjon: %1</translation>
     </message>
 </context>
 <context>
@@ -92,6 +100,74 @@ p, li { white-space: pre-wrap; }
         <translation>Legg til...</translation>
     </message>
 </context>
+<context>
+    <name>AdBlockBlockedNetworkReply</name>
+    <message>
+        <source>Blocked by AdBlockRule: %1</source>
+        <translation>Blokkert av AdBlockRule:%1</translation>
+    </message>
+</context>
+<context>
+    <name>AdBlockDialog</name>
+    <message>
+        <source>Add Custom Rule</source>
+        <translation>Legg til regel</translation>
+    </message>
+    <message>
+        <source>Learn more about writing rules...</source>
+        <translation>Lær mer om å skrive regler...</translation>
+    </message>
+    <message>
+        <source>Update Subscription</source>
+        <translation>Oppdater abonement</translation>
+    </message>
+    <message>
+        <source>Browse Subscriptions...</source>
+        <translation>Bla igjennom abonementer...</translation>
+    </message>
+    <message>
+        <source>Remove Subscription</source>
+        <translation>Fjern abonement</translation>
+    </message>
+    <message>
+        <source>AdBlock Configuration</source>
+        <translation>AdBlock konfigurasjon</translation>
+    </message>
+    <message>
+        <source>Enable AdBlock</source>
+        <translation>Skru på AdBlock</translation>
+    </message>
+    <message>
+        <source>Action</source>
+        <translation>Handling</translation>
+    </message>
+</context>
+<context>
+    <name>AdBlockManager</name>
+    <message>
+        <source>Custom Rules</source>
+        <translation>Regel</translation>
+    </message>
+</context>
+<context>
+    <name>AdBlockModel</name>
+    <message>
+        <source>Rule</source>
+        <translation>Regel</translation>
+    </message>
+</context>
+<context>
+    <name>AdBlockSchemeAccessHandler</name>
+    <message>
+        <source>Subscribe?</source>
+        <translation>Abonemer?</translation>
+    </message>
+    <message>
+        <source>Subscribe to this AdBlock subscription?
+%1</source>
+        <translation>Abonemer på dette AdBlock abonementet? %1</translation>
+    </message>
+</context>
 <context>
     <name>AddBookmarkDialog</name>
     <message>
@@ -115,6 +191,47 @@ p, li { white-space: pre-wrap; }
         <translation>Legg til mappe</translation>
     </message>
 </context>
+<context>
+    <name>AutoFillDialog</name>
+    <message>
+        <source>Form Passwords</source>
+        <translation>Passord</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Fjern</translation>
+    </message>
+    <message>
+        <source>Remove All</source>
+        <translation>Fjern alle</translation>
+    </message>
+</context>
+<context>
+    <name>AutoFillManager</name>
+    <message>
+        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
+        <translation>&lt;b&gt;Vil du lagre dette passordet?&lt;/b&gt;&lt;br&gt;         Du kan se hvilke passord du har lagret og eventuelt slette dem under Egenskaper.</translation>
+    </message>
+    <message>
+        <source>Never for this site</source>
+        <translation>Aldri for denne siden</translation>
+    </message>
+    <message>
+        <source>Not now</source>
+        <translation>Ikke nå</translation>
+    </message>
+</context>
+<context>
+    <name>AutoFillModel</name>
+    <message>
+        <source>WebSite</source>
+        <translation>Nettside</translation>
+    </message>
+    <message>
+        <source>User Name</source>
+        <translation>Brukernavn</translation>
+    </message>
+</context>
 <context>
     <name>BookmarksDialog</name>
     <message>
@@ -226,37 +343,37 @@ p, li { white-space: pre-wrap; }
     <message>
         <source>Name Change</source>
         <comment>Undo bookmark title change</comment>
-        <translation type="unfinished"></translation>
+        <translation>Navneendring</translation>
     </message>
     <message>
         <source>Address Change</source>
         <comment>Undo bookmark url change</comment>
-        <translation type="unfinished"></translation>
+        <translation>Addresseendring</translation>
     </message>
     <message>
         <source>XBEL bookmarks</source>
-        <translation type="unfinished"></translation>
+        <translation>XBEL bokmerker</translation>
     </message>
     <message>
         <source>HTML Netscape bookmarks</source>
-        <translation type="unfinished"></translation>
+        <translation>HTML Netscape bokmerker</translation>
     </message>
     <message>
         <source>htmlToXBel tool required</source>
-        <translation type="unfinished"></translation>
+        <translation>trenger htmlToXBel verktøy</translation>
     </message>
     <message>
         <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
-        <translation type="unfinished"></translation>
+        <translation>htmlToXBel verktøyet som følger med Arora og som trengs for å importere HTML bokmerker, er ikke installert eller er ikke i søkebanene.</translation>
     </message>
     <message>
         <source>Loading Bookmark</source>
-        <translation type="unfinished"></translation>
+        <translation>Laster bokmerker</translation>
     </message>
     <message>
         <source>Error when loading HTML bookmarks: %1
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Feil ved lasting av HTML bokmerker: %1</translation>
     </message>
 </context>
 <context>
@@ -305,7 +422,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Bookmarks</source>
-        <translation type="unfinished">Bokmerker</translation>
+        <translation type="obsolete">Bokmerker</translation>
     </message>
 </context>
 <context>
@@ -330,7 +447,11 @@ Er du sikker på at du vil avslutte Arora?</translation>
     </message>
     <message>
         <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
-        <translation>Den lagrede økten blir ikke gjennoprettet siden det førte til at Arora krasjet.</translation>
+        <translation type="obsolete">Den lagrede økten blir ikke gjennoprettet siden det førte til at Arora krasjet.</translation>
+    </message>
+    <message>
+        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
+        <translation>Arora kræsjet forrige gang vi prøvde å gjennoprette denne siden. Skal vi prøve igjenn?</translation>
     </message>
 </context>
 <context>
@@ -417,7 +538,7 @@ Er du sikker på at du vil avslutte Arora?</translation>
     </message>
     <message>
         <source>Shift+Ctrl+B</source>
-        <translation>Shift+Ctrl+B</translation>
+        <translation type="obsolete">Shift+Ctrl+B</translation>
     </message>
     <message>
         <source>Ctrl+|</source>
@@ -643,7 +764,7 @@ Vil du laste alle sider på nytt?</translation>
     </message>
     <message>
         <source>Prefere&amp;nces...</source>
-        <translation>&amp;Instillinger...</translation>
+        <translation type="obsolete">&amp;Instillinger...</translation>
     </message>
     <message>
         <source>Show Menu Bar</source>
@@ -701,15 +822,75 @@ Vil du laste alle sider på nytt?</translation>
     </message>
     <message>
         <source>Default</source>
-        <translation type="unfinished">Standardspråk</translation>
+        <translation>Forvalg</translation>
     </message>
     <message>
         <source>Text Encoding</source>
-        <translation type="unfinished"></translation>
+        <translation>Tekstkoding</translation>
     </message>
     <message>
-        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
-        <translation type="unfinished"></translation>
+        <source>Select &amp;All</source>
+        <translation>Velg &amp;alt</translation>
+    </message>
+    <message>
+        <source>Alt+Ctrl+B</source>
+        <translation>Alt+Ctrl+B</translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; No new network cache is written to disk.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
+        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Noen handlinger relatert til dine personlige opplysninger vil bli deaktiverte når privat surfing er skrudd på:&lt;ul&gt;&lt;li&gt; Nettsider blir ikke lagt til i historien.&lt;/li&gt;&lt;li&gt; Elementer blir automatisk fjernet fra Nedlastninger vinduet.&lt;/li&gt;&lt;li&gt; Nye informasjonskapsler blir ikke lagret og gamle kan ikke åpnes.&lt;/li&gt;&lt;li&gt; Ikoner og økter blir ikke lagret.&lt;/li&gt;&lt;li&gt; Søk blir ikke lagt til i sprett-opp menyen i søkeboksen.&lt;/li&gt;&lt;/ul&gt;Du kan fremdeles klikke Tilbake og Fram intill du lukker vinduet.</translation>
+    </message>
+    <message>
+        <source>Options...</source>
+        <translation>Alternativer...</translation>
+    </message>
+    <message>
+        <source>Configure Search Engines...</source>
+        <translation>Konfigurer søkemotorer...</translation>
+    </message>
+    <message>
+        <source>&amp;Ad Block...</source>
+        <translation>&amp;AdBlock...</translation>
+    </message>
+    <message>
+        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
+        <translation>Så lenge privat surfing er skrudd på, vil noen handlinger være skrudd av:</translation>
+    </message>
+    <message>
+        <source>Webpages are not added to the history.</source>
+        <translation>Nettsider blir ikke lagt til i historien.</translation>
+    </message>
+    <message>
+        <source>Items are automatically removed from the Downloads window.</source>
+        <translation>Nedlastninger blir automatisk fjernet fra Nedlastninger vinduet.</translation>
+    </message>
+    <message>
+        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
+        <translation>Nye informasjonskapsler blir ikke lagret og eksisterende informasjonskapsler kan ikke brukes.</translation>
+    </message>
+    <message>
+        <source>Site icons won&apos;t be stored.</source>
+        <translation>Nettsideikoner blir ikke lagret.</translation>
+    </message>
+    <message>
+        <source>Session won&apos;t be saved.</source>
+        <translation>Sessjoner blir ikke lagret.</translation>
+    </message>
+    <message>
+        <source>Searches are not added to the pop-up menu in the search box.</source>
+        <translation>Søk blir ikke lagt til i søkemenyen.</translation>
+    </message>
+    <message>
+        <source>No new network cache is written to disk.</source>
+        <translation>Nettverkshurtiglageret blir ikke skrevet til platelageret.</translation>
+    </message>
+    <message>
+        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
+        <translation>Så lenge du ikke lukker vinduet kan du fremdeles klikke Fram og Tilbake for å se sider du har åpnet.</translation>
+    </message>
+    <message>
+        <source>Private Browsing</source>
+        <translation>Privat surfing</translation>
     </message>
 </context>
 <context>
@@ -770,34 +951,34 @@ Vil du laste alle sider på nytt?</translation>
     <name>ClickToFlash</name>
     <message>
         <source>Load</source>
-        <translation type="unfinished"></translation>
+        <translation>Last</translation>
     </message>
     <message>
         <source>Load All</source>
-        <translation type="unfinished"></translation>
+        <translation>Last alle</translation>
     </message>
     <message>
         <source>Add %1 to Whitelist</source>
-        <translation type="unfinished"></translation>
+        <translation>Legg til %1 i godkjentlisten</translation>
     </message>
     <message>
         <source>Remove from Whitelist</source>
-        <translation type="unfinished"></translation>
+        <translation>Fjern fra godkjentlisten</translation>
     </message>
     <message>
         <source>Settings</source>
-        <translation type="unfinished">Innstilinger</translation>
+        <translation>Innstilinger</translation>
     </message>
     <message>
         <source>Load Flash</source>
-        <translation type="unfinished"></translation>
+        <translation>Last Flash</translation>
     </message>
 </context>
 <context>
     <name>ClickToFlashSettings</name>
     <message>
         <source>Whitelist sites</source>
-        <translation type="unfinished"></translation>
+        <translation>Godkjente sider</translation>
     </message>
 </context>
 <context>
@@ -863,7 +1044,7 @@ Vil du laste alle sider på nytt?</translation>
     </message>
     <message>
         <source>Session cookie</source>
-        <translation type="unfinished"></translation>
+        <translation>Sesjonsinformasjonskapsel</translation>
     </message>
 </context>
 <context>
@@ -882,7 +1063,7 @@ Vil du laste alle sider på nytt?</translation>
     </message>
     <message>
         <source>Add &amp;Rule</source>
-        <translation type="unfinished"></translation>
+        <translation>Legg til &amp;regel</translation>
     </message>
 </context>
 <context>
@@ -1041,7 +1222,7 @@ Vil du laste alle sider på nytt?</translation>
     </message>
     <message>
         <source>Download directory (%1) couldn&apos;t be created.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nedlastningsbanen (%1) kunne ikke opprettes.</translation>
     </message>
 </context>
 <context>
@@ -1087,30 +1268,30 @@ Er du sikker på at du vil avslutte?</translation>
     </message>
     <message>
         <source>GB</source>
-        <translation type="unfinished"></translation>
+        <translation>GB</translation>
     </message>
 </context>
 <context>
     <name>FileAccessReply</name>
     <message>
         <source>No Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Ingen feil</translation>
     </message>
     <message>
         <source>Error opening: %1: No such file or directory</source>
-        <translation type="unfinished"></translation>
+        <translation>Feil ved åpning av: %1: Filen eller banen finnes ikke</translation>
     </message>
     <message>
         <source>Unable to read %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Kan ikke lese %1</translation>
     </message>
     <message>
         <source>Contents of %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Innhold i %1</translation>
     </message>
     <message>
         <source>%1 KB</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 KB</translation>
     </message>
 </context>
 <context>
@@ -1188,23 +1369,23 @@ Er du sikker på at du vil avslutte?</translation>
     <name>JavaScriptAroraObject</name>
     <message>
         <source>Welcome to Arora!</source>
-        <translation type="unfinished"></translation>
+        <translation>Velkommen til Arora!</translation>
     </message>
     <message>
         <source>Arora Start</source>
-        <translation type="unfinished"></translation>
+        <translation>Arora start</translation>
     </message>
     <message>
         <source>Search!</source>
-        <translation type="unfinished"></translation>
+        <translation>Søk!</translation>
     </message>
     <message>
         <source>Search results provided by</source>
-        <translation type="unfinished"></translation>
+        <translation>Søkeresultater levert av</translation>
     </message>
     <message>
         <source>About Arora</source>
-        <translation type="unfinished"></translation>
+        <translation>Om Arora</translation>
     </message>
 </context>
 <context>
@@ -1223,7 +1404,11 @@ Er du sikker på at du vil avslutte?</translation>
     </message>
     <message>
         <source>No translation files are installed.</source>
-        <translation>Ingen oversettelses filer er installert.</translation>
+        <translation type="obsolete">Ingen oversettelses filer er installert.</translation>
+    </message>
+    <message>
+        <source>No translation files are installed at %1.</source>
+        <translation>Ingen oversettelsesfiler er installert i %1.</translation>
     </message>
 </context>
 <context>
@@ -1274,23 +1459,23 @@ Vil du ignorere disse feilene?&lt;qt&gt;</translation>
     </message>
     <message>
         <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;qt&gt;Sertifikater:&lt;br/&gt;%1&lt;br/&gt;Vil du akseptere alle disse sertifikatene?&lt;/qt&gt;</translation>
     </message>
     <message>
         <source>Issuer: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Utsteder: %1</translation>
     </message>
     <message>
         <source>Not valid before: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Ikke gyldig før: %1</translation>
     </message>
     <message>
         <source>Valid until: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Gyldig inntil: %1</translation>
     </message>
     <message>
         <source>Alternate Names:</source>
-        <translation type="unfinished"></translation>
+        <translation>Alternative navn:</translation>
     </message>
 </context>
 <context>
@@ -1335,61 +1520,73 @@ Vil du ignorere disse feilene?&lt;qt&gt;</translation>
     <name>OpenSearchDialog</name>
     <message>
         <source>Open File</source>
-        <translation type="unfinished">Åpne fil</translation>
+        <translation>Åpne fil</translation>
     </message>
     <message>
         <source>OpenSearch</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenSearch</translation>
     </message>
     <message>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Feil</translation>
     </message>
     <message>
         <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 er ikke en gyldig OpenSearch 1.1 beskrivelse, eller så finnes den allerede i listen.</translation>
     </message>
     <message>
         <source>You must have at least one search engine in here.</source>
-        <translation type="unfinished"></translation>
+        <translation>Det må være minst en søkemotor her.</translation>
     </message>
     <message>
         <source>OpenSearch Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenSearch-behandler</translation>
     </message>
     <message>
         <source>&amp;Restore Defaults</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Gjennoprett forvalg</translation>
     </message>
     <message>
         <source>&amp;Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Slett</translation>
     </message>
     <message>
         <source>&amp;Add</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Legg til</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Lukk</translation>
     </message>
 </context>
 <context>
     <name>OpenSearchEngineModel</name>
     <message>
         <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;strong&gt;Beskrivelse:&lt;/strong&gt; %1</translation>
     </message>
     <message>
         <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
+        <translation>&lt;strong&gt;Gir forslag&lt;/strong&gt;</translation>
+    </message>
+    <message>
+        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Name</source>
+        <translation>Navn</translation>
+    </message>
+    <message>
+        <source>Keywords</source>
+        <translation>Nøkkelord</translation>
+    </message>
 </context>
 <context>
     <name>OpenSearchManager</name>
     <message>
         <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Vil du legge til den følgende motoren i listen over søkemotorer?&lt;br /&gt;&lt;br /&gt;Navn: %1&lt;br /&gt;Søker på: %2</translation>
     </message>
 </context>
 <context>
@@ -1453,7 +1650,7 @@ Vil du ignorere disse feilene?&lt;qt&gt;</translation>
     </message>
     <message>
         <source>The file is not an OpenSearch 1.1 file.</source>
-        <translation type="unfinished"></translation>
+        <translation>Filen er ikke en OpenSearch 1.1 fil.</translation>
     </message>
 </context>
 <context>
@@ -1500,7 +1697,7 @@ Vil du ignorere disse feilene?&lt;qt&gt;</translation>
     </message>
     <message>
         <source>Highlight All</source>
-        <translation type="unfinished"></translation>
+        <translation>Merk alt</translation>
     </message>
 </context>
 <context>
@@ -1811,46 +2008,106 @@ Vil du ignorere disse feilene?&lt;qt&gt;</translation>
     </message>
     <message>
         <source>Use ClickToFlash on flash plugins</source>
-        <translation type="unfinished"></translation>
+        <translation>Bruk ClickToFlash på flash-programtillegg</translation>
     </message>
     <message>
         <source>Filter Tracking Cookies</source>
-        <translation type="unfinished"></translation>
+        <translation>Filtrer ut sporingsinformasjonskapsler</translation>
     </message>
     <message>
         <source>Confirm when closing multiple tabs or windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Be om bekreftelse for å lukke flere faner eller viduer</translation>
     </message>
     <message>
         <source>Quit the application when last tab is closed</source>
-        <translation type="unfinished"></translation>
+        <translation>Lukk programmet når siste fane blir lukket</translation>
     </message>
     <message>
         <source>Enable network cache</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktiver nettverkshurtiglager</translation>
     </message>
     <message>
         <source>Maximum Size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Maksimal størrelse:</translation>
     </message>
     <message>
         <source> MB</source>
-        <translation type="unfinished"></translation>
+        <translation>MB</translation>
     </message>
     <message>
         <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
-        <translation type="unfinished"></translation>
+        <translation>Bruk standardsøkemotoren hvis URLen gitt av brukeren er ugyldig</translation>
+    </message>
+    <message>
+        <source>Choose Directory...</source>
+        <translation>Velg katalog...</translation>
+    </message>
+    <message>
+        <source>A cookie session ends:</source>
+        <translation>En informasjonskapselsesjon slutter:</translation>
+    </message>
+    <message>
+        <source>When I exit the application</source>
+        <translation>Når jeg skruv av programmet</translation>
+    </message>
+    <message>
+        <source>1 day</source>
+        <translation>1 dag</translation>
+    </message>
+    <message>
+        <source>2 days</source>
+        <translation>2 dager</translation>
+    </message>
+    <message>
+        <source>3 days</source>
+        <translation>3 dager</translation>
+    </message>
+    <message>
+        <source>7 days</source>
+        <translation>7 dager</translation>
+    </message>
+    <message>
+        <source>30 days</source>
+        <translation>30 dager</translation>
+    </message>
+    <message>
+        <source>AutoFill</source>
+        <translation>AutoFill</translation>
+    </message>
+    <message>
+        <source>AutoFill web forms:</source>
+        <translation>AutoFill skjemaer:</translation>
+    </message>
+    <message>
+        <source>User names and passwords</source>
+        <translation>Brukernavn og passord</translation>
+    </message>
+    <message>
+        <source>Edit...</source>
+        <translation>Rediger...</translation>
+    </message>
+    <message>
+        <source>Browse...</source>
+        <translation>Bla igjennom...</translation>
     </message>
 </context>
 <context>
     <name>SettingsDialog</name>
     <message>
         <source>Restart required</source>
-        <translation type="unfinished"></translation>
+        <translation>Omstart påkrevd</translation>
     </message>
     <message>
         <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nettverkshurtiglagerkonfigurasjonen har blitt endret. Nettleseren må startes på nytt for å kunne bruke endringene.</translation>
+    </message>
+    <message>
+        <source>Choose Directory</source>
+        <translation>Velg katalog</translation>
+    </message>
+    <message>
+        <source>Choose CSS File</source>
+        <translation>Velg CSS fil</translation>
     </message>
 </context>
 <context>
@@ -1869,11 +2126,11 @@ Vil du ignorere disse feilene?&lt;qt&gt;</translation>
     </message>
     <message>
         <source>&amp;View</source>
-        <translation>&amp;Vis</translation>
+        <translation type="obsolete">&amp;Vis</translation>
     </message>
     <message>
         <source>&amp;Wrap lines</source>
-        <translation>&amp;Bryt linjer</translation>
+        <translation type="obsolete">&amp;Bryt linjer</translation>
     </message>
     <message>
         <source>Source of Page </source>
@@ -1881,7 +2138,7 @@ Vil du ignorere disse feilene?&lt;qt&gt;</translation>
     </message>
     <message>
         <source>Source of Page %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Kildekoden til %1</translation>
     </message>
 </context>
 <context>
@@ -2010,7 +2267,7 @@ Vil du virkelig lukke denne siden?
     </message>
     <message>
         <source>Clear Recent Searches</source>
-        <translation type="unfinished">Slett nylige søk</translation>
+        <translation>Slett nylige søk</translation>
     </message>
     <message>
         <source>Suggestions</source>
@@ -2018,11 +2275,11 @@ Vil du virkelig lukke denne siden?
     </message>
     <message>
         <source>Add &apos;%1&apos;</source>
-        <translation type="unfinished"></translation>
+        <translation>Legg til &apos;%1&apos;</translation>
     </message>
     <message>
         <source>Configure Search Engines...</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Konfigurer søkemotorer...</translation>
     </message>
 </context>
 <context>
@@ -2057,11 +2314,11 @@ Vil du virkelig lukke denne siden?
     </message>
     <message>
         <source>Resending POST request</source>
-        <translation type="unfinished"></translation>
+        <translation>Sender POST forespørsel på nytt</translation>
     </message>
     <message>
         <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
-        <translation type="unfinished"></translation>
+        <translation>Forespørselen, sammen med all dataen, må sendes på nytt for å kunne vise siden. Dette kan føre til uforutsette konsekvenser. F.eks., kan den samme handlingen bli utført flere ganger. Vil du fortsette?</translation>
     </message>
 </context>
 <context>
@@ -2112,35 +2369,39 @@ Vil du virkelig lukke denne siden?
     </message>
     <message>
         <source>Search with...</source>
-        <translation type="unfinished"></translation>
+        <translation>Søk med...</translation>
     </message>
     <message>
         <source>Add to the toolbar search</source>
-        <translation type="unfinished"></translation>
+        <translation>Legg til i søkeverktøylinja</translation>
     </message>
     <message>
         <source>Method not supported</source>
-        <translation type="unfinished"></translation>
+        <translation>Metoden er ikke støttet</translation>
     </message>
     <message>
         <source>%1 method is not supported.</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 metoden er ikke støttet.</translation>
     </message>
     <message>
         <source>Search engine</source>
-        <translation type="unfinished"></translation>
+        <translation>Søkemotor</translation>
     </message>
     <message>
         <source>Choose the desired search engine</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg den ønskede søkemotoren</translation>
     </message>
     <message>
         <source>Engine name</source>
-        <translation type="unfinished"></translation>
+        <translation>Søkemotorens navn</translation>
     </message>
     <message>
         <source>Type in a name for the engine</source>
-        <translation type="unfinished"></translation>
+        <translation>Gi søkemotoren et navn</translation>
+    </message>
+    <message>
+        <source>Block Image</source>
+        <translation>Blokker bilde</translation>
     </message>
 </context>
 <context>
