@@ -39,6 +39,10 @@ p, li { white-space: pre-wrap; }
         <source>Close</source>
         <translation>Затвори</translation>
     </message>
+    <message>
+        <source>WebKit version: %1</source>
+        <translation>Верзија Вебкита: %1</translation>
+    </message>
 </context>
 <context>
     <name>AcceptLanguage</name>
@@ -48,7 +52,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Languages: in order of preference:</source>
-        <translation>Језици: Према редоследу пожељности:</translation>
+        <translation>Језици према редоследу пожељности:</translation>
     </message>
     <message>
         <source>Move &amp;Up</source>
@@ -67,6 +71,75 @@ p, li { white-space: pre-wrap; }
         <translation>Додај...</translation>
     </message>
 </context>
+<context>
+    <name>AdBlockBlockedNetworkReply</name>
+    <message>
+        <source>Blocked by AdBlockRule: %1</source>
+        <translation>Заустављено Адблоковим правилом: %1</translation>
+    </message>
+</context>
+<context>
+    <name>AdBlockDialog</name>
+    <message>
+        <source>Add Custom Rule</source>
+        <translation>Додај прилагођено правило</translation>
+    </message>
+    <message>
+        <source>Learn more about writing rules...</source>
+        <translation>Научите више о писању правила...</translation>
+    </message>
+    <message>
+        <source>Update Subscription</source>
+        <translation>Ажурирај претплате</translation>
+    </message>
+    <message>
+        <source>Browse Subscriptions...</source>
+        <translation>Прегледај претплате...</translation>
+    </message>
+    <message>
+        <source>Remove Subscription</source>
+        <translation>Уклони претплату</translation>
+    </message>
+    <message>
+        <source>AdBlock Configuration</source>
+        <translation>Подешавање Адблока</translation>
+    </message>
+    <message>
+        <source>Enable AdBlock</source>
+        <translation>Омогући Адблок</translation>
+    </message>
+    <message>
+        <source>Action</source>
+        <translation>Радња</translation>
+    </message>
+</context>
+<context>
+    <name>AdBlockManager</name>
+    <message>
+        <source>Custom Rules</source>
+        <translation>Прилагођена правила</translation>
+    </message>
+</context>
+<context>
+    <name>AdBlockModel</name>
+    <message>
+        <source>Rule</source>
+        <translation>Правило</translation>
+    </message>
+</context>
+<context>
+    <name>AdBlockSchemeAccessHandler</name>
+    <message>
+        <source>Subscribe?</source>
+        <translation>Претплати се?</translation>
+    </message>
+    <message>
+        <source>Subscribe to this AdBlock subscription?
+%1</source>
+        <translation>Претпалтити се на ову Адблок претплату?
+%1</translation>
+    </message>
+</context>
 <context>
     <name>AddBookmarkDialog</name>
     <message>
@@ -83,13 +156,54 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Title</source>
-        <translation>Назив</translation>
+        <translation>Наслов</translation>
     </message>
     <message>
         <source>Add Folder</source>
         <translation>Додај фасциклу</translation>
     </message>
 </context>
+<context>
+    <name>AutoFillDialog</name>
+    <message>
+        <source>Form Passwords</source>
+        <translation>Лозинке за обрасце</translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation>Уклони</translation>
+    </message>
+    <message>
+        <source>Remove All</source>
+        <translation>Уклони све</translation>
+    </message>
+</context>
+<context>
+    <name>AutoFillManager</name>
+    <message>
+        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
+        <translation>&lt;b&gt;Желите ли да сачувате ову лозинку?&lt;/b&gt;&lt;br&gt;         Да би прегледали или уклонили сачуване лозинке користите панел самопопуњавања у подешавањима.</translation>
+    </message>
+    <message>
+        <source>Never for this site</source>
+        <translation>Никад за овај сајт</translation>
+    </message>
+    <message>
+        <source>Not now</source>
+        <translation>Не сад</translation>
+    </message>
+</context>
+<context>
+    <name>AutoFillModel</name>
+    <message>
+        <source>WebSite</source>
+        <translation>Веб сајт</translation>
+    </message>
+    <message>
+        <source>User Name</source>
+        <translation>Корисничко име</translation>
+    </message>
+</context>
 <context>
     <name>BookmarksDialog</name>
     <message>
@@ -157,16 +271,6 @@ p, li { white-space: pre-wrap; }
         <source>Open File</source>
         <translation>Отвори фајл</translation>
     </message>
-    <message>
-        <source>XBEL</source>
-        <translation type="obsolete">ИксБЕЛ</translation>
-    </message>
-    <message>
-        <source>Error when loading html bookmarks: %1
-</source>
-        <translation type="obsolete">Грешка при учитавању хтмл маркера: %1
-</translation>
-    </message>
     <message>
         <source>Imported %1</source>
         <translation>Увезено %1</translation>
@@ -179,10 +283,6 @@ p, li { white-space: pre-wrap; }
         <source>%1 Bookmarks.xbel</source>
         <translation>%1 Маркери.xbel</translation>
     </message>
-    <message>
-        <source>XBEL (*.xbel *.xml)</source>
-        <translation type="obsolete">ИксБЕЛ (*.xbel *.xml)</translation>
-    </message>
     <message>
         <source>Export error</source>
         <translation>Грешка при извозу</translation>
@@ -247,7 +347,7 @@ p, li { white-space: pre-wrap; }
     <name>BookmarksModel</name>
     <message>
         <source>Title</source>
-        <translation>Назив</translation>
+        <translation>Наслов</translation>
     </message>
     <message>
         <source>Address</source>
@@ -256,10 +356,6 @@ p, li { white-space: pre-wrap; }
 </context>
 <context>
     <name>BookmarksToolBar</name>
-    <message>
-        <source>Bookmark</source>
-        <translation type="obsolete">Маркери</translation>
-    </message>
     <message>
         <source>Open</source>
         <translation>Отвори</translation>
@@ -280,30 +376,22 @@ p, li { white-space: pre-wrap; }
         <source>Add Folder...</source>
         <translation>Додај фасциклу...</translation>
     </message>
-    <message>
-        <source>Bookmarks</source>
-        <translation>Маркери</translation>
-    </message>
 </context>
 <context>
     <name>BrowserApplication</name>
-    <message>
-        <source> (Change: %1 %2)</source>
-        <translation type="obsolete">(Ревизија: %1 %2)</translation>
-    </message>
     <message>
         <source>There are %1 windows and %2 tabs open
 Do you want to quit anyway?</source>
         <translation>Отворено је  %1 прозор(а) и %2 језичак(а)
-Да ли свеједно желите да напустите?</translation>
+Свеједно напустити?</translation>
     </message>
     <message>
         <source>Restore failed</source>
         <translation>Повраћај није успео</translation>
     </message>
     <message>
-        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
-        <translation>Сачувана сесија неће бити повраћена јер се Арора срушила покушавајући да је поврати.</translation>
+        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
+        <translation>Арора се срушила у покушају да поврати сесију. Покушати поново?</translation>
     </message>
 </context>
 <context>
@@ -392,10 +480,6 @@ Do you want to quit anyway?</source>
         <source>Find P&amp;revious</source>
         <translation>Нађи &amp;претходно</translation>
     </message>
-    <message>
-        <source>Prefere&amp;nces...</source>
-        <translation>Поста&amp;вке...</translation>
-    </message>
     <message>
         <source>Ctrl+,</source>
         <translation>Ctrl+,</translation>
@@ -408,10 +492,6 @@ Do you want to quit anyway?</source>
         <source>Ctrl+|</source>
         <translation>Ctrl+|</translation>
     </message>
-    <message>
-        <source>Shift+Ctrl+B</source>
-        <translation>Shift+Ctrl+B</translation>
-    </message>
     <message>
         <source>Ctrl+/</source>
         <translation>Ctrl+/</translation>
@@ -518,10 +598,6 @@ Do you want to quit anyway?</source>
         <comment>Clear Private Data</comment>
         <translation>Ctrl+Shift+Delete</translation>
     </message>
-    <message>
-        <source>Show &amp;Network Monitor</source>
-        <translation type="obsolete">Прикажи мон&amp;итор мреже</translation>
-    </message>
     <message>
         <source>Enable Web &amp;Inspector</source>
         <translation>Омогући &amp;веб инспектор</translation>
@@ -592,10 +668,6 @@ Do you want to quit anyway?</source>
         <source>Are you sure you want to turn on private browsing?</source>
         <translation>Да ли сте сигурни да желите да укључите приватно прегледање?</translation>
     </message>
-    <message>
-        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
-        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Када је приватно прегледање укључено неке радње које се тичу ваше приватности ће бити онемогућене:&lt;ul&gt;&lt;li&gt;Веб странице се не додају у историјат.&lt;/li&gt;&lt;li&gt; Ставке се аутоматски уклањају из прозора преузимања.&lt;/li&gt;&lt;li&gt;Нови колачићи се не снимају, постојећима се не може приступити&lt;/li&gt;&lt;li&gt;Иконе странице се не чувају, сесије неће бити сачуване.&lt;/li&gt;&lt;li&gt;Претраге се не додају у искачући мени прозорчића претраге.&lt;/li&gt;&lt;/ul&gt;Док не затворите прозор и даље можете кликнути на Напред и Назад да би се вратили на претходно отворене странице.</translation>
-    </message>
     <message>
         <source>Are you sure you want to close the window?  There are %1 tabs open</source>
         <translation>Да ли сте сигурни да желите да затворите прозор? Отворен(о) је %1 језичак(а)</translation>
@@ -620,7 +692,7 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>Downloads</source>
-        <translation>Преузимања</translation>
+        <translation>Пријеми</translation>
     </message>
     <message>
         <source>Ctrl+Y</source>
@@ -636,8 +708,64 @@ Do you want to reload all pages?</source>
         <translation>Кодирање текста</translation>
     </message>
     <message>
-        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
-        <translation>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Када је приватно прегледање укључено неке радње које се тичу ваше приватности ће бити онемогућене:&lt;ul&gt;&lt;li&gt;Веб странице се не додају у историјат.&lt;/li&gt;&lt;li&gt; Ставке се аутоматски уклањају из прозора преузимања.&lt;/li&gt;&lt;li&gt;Нови колачићи се не снимају, постојећима се не може приступити&lt;/li&gt;&lt;li&gt;Иконе странице се не чувају, сесије неће бити сачуване.&lt;/li&gt;&lt;li&gt;Претраге се не додају у искачући мени прозорчића претраге.&lt;/li&gt;&lt;/ul&gt;Док не затворите прозор и даље можете кликнути на Напред и Назад да би се вратили на претходно отворене странице.</translation>
+        <source>Alt+Ctrl+B</source>
+        <translation>Alt+Ctrl+B</translation>
+    </message>
+    <message>
+        <source>Select &amp;All</source>
+        <translation>Изабери &amp;све</translation>
+    </message>
+    <message>
+        <source>Options...</source>
+        <translation>Опције...</translation>
+    </message>
+    <message>
+        <source>Configure Search Engines...</source>
+        <translation>Подеси моторе претраге...</translation>
+    </message>
+    <message>
+        <source>&amp;Ad Block...</source>
+        <translation>&amp;Адблок...</translation>
+    </message>
+    <message>
+        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
+        <translation>Кад је укључено приватно прегледање онемогућене су неке радње које се тичу ваше приватности:</translation>
+    </message>
+    <message>
+        <source>Webpages are not added to the history.</source>
+        <translation>Веб стране се не додају у историјат.</translation>
+    </message>
+    <message>
+        <source>Items are automatically removed from the Downloads window.</source>
+        <translation>Ставке се аутоматски уклањају из прозора пријема.</translation>
+    </message>
+    <message>
+        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
+        <translation>Нови колачићи се не чувају, постојећим се не може приступити.</translation>
+    </message>
+    <message>
+        <source>Site icons won&apos;t be stored.</source>
+        <translation>Иконе сајтова се не чувају.</translation>
+    </message>
+    <message>
+        <source>Session won&apos;t be saved.</source>
+        <translation>Сесије се не снимају.</translation>
+    </message>
+    <message>
+        <source>Searches are not added to the pop-up menu in the search box.</source>
+        <translation>Претраге се не додају у искачући мени прозорчића претраге.</translation>
+    </message>
+    <message>
+        <source>No new network cache is written to disk.</source>
+        <translation>Мрежни кеш се не дописује на диск.</translation>
+    </message>
+    <message>
+        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
+        <translation>Док не затворите прозор и даље можете кликнути на „Напред“ и „Назад“ да би сте се вратили на претходно отваране странице.</translation>
+    </message>
+    <message>
+        <source>Private Browsing</source>
+        <translation>Приватно прегледање</translation>
     </message>
 </context>
 <context>
@@ -659,27 +787,27 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>&amp;Browsing History</source>
-        <translation>Историјат &amp;претраге</translation>
+        <translation>историјат &amp;претраге</translation>
     </message>
     <message>
         <source>&amp;Download History</source>
-        <translation>Историјат п&amp;реузимања</translation>
+        <translation>историјат п&amp;реузимања</translation>
     </message>
     <message>
         <source>&amp;Search History</source>
-        <translation>Историјат пр&amp;етраге</translation>
+        <translation>историјат пр&amp;етраге</translation>
     </message>
     <message>
         <source>&amp;Cookies</source>
-        <translation>&amp;Колачићи</translation>
+        <translation>&amp;колачиће</translation>
     </message>
     <message>
         <source>C&amp;ached Web Pages</source>
-        <translation>Кеширане &amp;веб странице</translation>
+        <translation>кеширане &amp;веб странице</translation>
     </message>
     <message>
         <source>Website &amp;Icons</source>
-        <translation>&amp;Иконе веб сајтова</translation>
+        <translation>&amp;иконе веб сајтова</translation>
     </message>
     <message>
         <source>Clear &amp;Private Data</source>
@@ -858,17 +986,9 @@ Do you want to reload all pages?</source>
         <source>0 Items</source>
         <translation>Нема ставки</translation>
     </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation type="obsolete">&amp;OK</translation>
-    </message>
 </context>
 <context>
     <name>DownloadItem</name>
-    <message>
-        <source>Form</source>
-        <translation type="obsolete">Формулар</translation>
-    </message>
     <message>
         <source>Ico</source>
         <translation>Икона</translation>
@@ -932,7 +1052,7 @@ Do you want to reload all pages?</source>
         <source>There are %1 downloads in progress
 Do you want to quit anyway?</source>
         <translation>У току су %1 преузимања
-Да ли свеједно желите да напустите?</translation>
+Свеједно напустити?</translation>
     </message>
     <message numerus="yes">
         <source>%n Download(s)</source>
@@ -1041,7 +1161,7 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>Do you want to clear the history?</source>
-        <translation>Да ли желите да очистите историјат?</translation>
+        <translation>Желите ли да очистите историјат?</translation>
     </message>
 </context>
 <context>
@@ -1095,17 +1215,17 @@ Do you want to quit anyway?</source>
 </context>
 <context>
     <name>LanguageManager</name>
-    <message>
-        <source>No translation files are installed.</source>
-        <translation>Нема инсталираних фајлова превода.</translation>
-    </message>
     <message>
         <source>Choose language</source>
         <translation>Изаберите језик</translation>
     </message>
     <message>
         <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
-        <translation>&lt;p&gt;Можете поставити различит језик од оног&lt;br&gt;који оперативни систем подразумева.&lt;/p&gt;&lt;p&gt;Молим изаберите језик који би требало користити&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;Можете поставити различит језик од оног&lt;br&gt;који оперативни систем подразумева.&lt;/p&gt;&lt;p&gt;Изаберите језик који ћете користити&lt;/p&gt;</translation>
+    </message>
+    <message>
+        <source>No translation files are installed at %1.</source>
+        <translation>Нема инсталираних фајлова превода у %1.</translation>
     </message>
 </context>
 <context>
@@ -1122,12 +1242,6 @@ Do you want to quit anyway?</source>
         <source> - SSL Errors</source>
         <translation>- SSL грешке</translation>
     </message>
-    <message>
-        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;
-Do you want to ignore these errors?&lt;/qt&gt;</source>
-        <translation type="obsolete">&lt;qt&gt;SSL грешке:&lt;br/&gt;&lt;br/&gt;за: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;
-Да ли желите да занемарите ове грешке?&lt;/qt&gt;</translation>
-    </message>
     <message>
         <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;Сертификати:&lt;br/&gt;%1&lt;br/&gt;Да ли желите да прихватите све ове сертификате?&lt;/qt&gt;</translation>
@@ -1156,44 +1270,6 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
         <translation>Алтернативни називи:</translation>
     </message>
 </context>
-<context>
-    <name>NetworkMonitor</name>
-    <message>
-        <source>Name</source>
-        <translation type="obsolete">Име</translation>
-    </message>
-    <message>
-        <source>Value</source>
-        <translation type="obsolete">Вредност</translation>
-    </message>
-</context>
-<context>
-    <name>NetworkMonitorDialog</name>
-    <message>
-        <source>Network Monitor</source>
-        <translation type="obsolete">Монитор мреже</translation>
-    </message>
-    <message>
-        <source>Network Requests</source>
-        <translation type="obsolete">Мрежни захтеви</translation>
-    </message>
-    <message>
-        <source>Request Headers</source>
-        <translation type="obsolete">Заглавља захтева</translation>
-    </message>
-    <message>
-        <source>Response Headers</source>
-        <translation type="obsolete">Заглавља одговора</translation>
-    </message>
-    <message>
-        <source>&amp;Remove</source>
-        <translation type="obsolete">&amp;Уклони</translation>
-    </message>
-    <message>
-        <source>Remove &amp;All Requests</source>
-        <translation type="obsolete">Уклони &amp;све захтеве</translation>
-    </message>
-</context>
 <context>
     <name>OpenSearchDialog</name>
     <message>
@@ -1247,19 +1323,31 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
         <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
         <translation>&lt;strong&gt;Даје предлоге из садржаја&lt;/strong&gt;</translation>
     </message>
+    <message>
+        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
+        <translation>Списак зарезом раздвојених кључних речи које могу бити унете у траку локације заједно са изразима са претрагу у овом мотору претраге</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Име</translation>
+    </message>
+    <message>
+        <source>Keywords</source>
+        <translation>Кључне речи</translation>
+    </message>
 </context>
 <context>
     <name>OpenSearchManager</name>
     <message>
         <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
-        <translation>Да ли желите да додате следећи мотор на вашу листу мотора претраге? &lt;br /&gt;&lt;br /&gt;Име: %1&lt;br /&gt;Претражује на: %2</translation>
+        <translation>Желите ли да додате следећи мотор на вашу листу мотора претраге? &lt;br /&gt;&lt;br /&gt;Име: %1&lt;br /&gt;Претражује на: %2</translation>
     </message>
 </context>
 <context>
     <name>PasswordDialog</name>
     <message>
         <source>Authentication Required</source>
-        <translation>Захтева се аутентификација</translation>
+        <translation>Неопходна аутентификација</translation>
     </message>
     <message>
         <source>DUMMY ICON</source>
@@ -1319,47 +1407,8 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
         <translation>Фајл није OpenSearch 1.1 типа.</translation>
     </message>
 </context>
-<context>
-    <name>RequestModel</name>
-    <message>
-        <source>Redirect: %1</source>
-        <translation type="obsolete">Преусмеравање: %1</translation>
-    </message>
-    <message>
-        <source>Method</source>
-        <translation type="obsolete">Метод</translation>
-    </message>
-    <message>
-        <source>Address</source>
-        <translation type="obsolete">Адреса</translation>
-    </message>
-    <message>
-        <source>Response</source>
-        <translation type="obsolete">Одговор</translation>
-    </message>
-    <message>
-        <source>Length</source>
-        <translation type="obsolete">Трајање</translation>
-    </message>
-    <message>
-        <source>Content Type</source>
-        <translation type="obsolete">Тип садржаја</translation>
-    </message>
-    <message>
-        <source>Info</source>
-        <translation type="obsolete">Информације</translation>
-    </message>
-    <message>
-        <source>Unknown</source>
-        <translation type="obsolete">Непознато</translation>
-    </message>
-</context>
 <context>
     <name>SearchBanner</name>
-    <message>
-        <source>Form</source>
-        <translation type="obsolete">Формулар</translation>
-    </message>
     <message>
         <source>Done</source>
         <translation>Завршено</translation>
@@ -1392,23 +1441,23 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
     </message>
     <message>
         <source>Show my home page</source>
-        <translation>Прикажи моју страницу</translation>
+        <translation>прикажи домаћу страницу</translation>
     </message>
     <message>
         <source>Show a blank page</source>
-        <translation>Прикажи празну страницу</translation>
+        <translation>прикажи празну страницу</translation>
     </message>
     <message>
         <source>Restore windows and tabs from last time</source>
-        <translation>Поврати прозоре и језичке од прошлог пута</translation>
+        <translation>поврати прозоре и језичке од прошлог пута</translation>
     </message>
     <message>
         <source>Home Page:</source>
-        <translation>Моја страница:</translation>
+        <translation>Домаћа страница:</translation>
     </message>
     <message>
         <source>Set to current page</source>
-        <translation>Користи тренутну страницу</translation>
+        <translation>Постави текућу страницу</translation>
     </message>
     <message>
         <source>Remove history items:</source>
@@ -1416,31 +1465,31 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
     </message>
     <message>
         <source>After one day</source>
-        <translation>После једног дана</translation>
+        <translation>после једног дана</translation>
     </message>
     <message>
         <source>After one week</source>
-        <translation>После једне седмице</translation>
+        <translation>после једне седмице</translation>
     </message>
     <message>
         <source>After two weeks</source>
-        <translation>После две седмице</translation>
+        <translation>после две седмице</translation>
     </message>
     <message>
         <source>After one month</source>
-        <translation>После једног месеца</translation>
+        <translation>после једног месеца</translation>
     </message>
     <message>
         <source>After one year</source>
-        <translation>После једне године</translation>
+        <translation>после једне године</translation>
     </message>
     <message>
         <source>Manually</source>
-        <translation>Ручно</translation>
+        <translation>ручно</translation>
     </message>
     <message>
         <source>On application exit</source>
-        <translation>При гашењу програма</translation>
+        <translation>при напуштању програма</translation>
     </message>
     <message>
         <source>Downloads</source>
@@ -1512,15 +1561,15 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
     </message>
     <message>
         <source>Always</source>
-        <translation>Увек</translation>
+        <translation>увек</translation>
     </message>
     <message>
         <source>Never</source>
-        <translation>Никад</translation>
+        <translation>никад</translation>
     </message>
     <message>
         <source>Only from sites you navigate to</source>
-        <translation>Само са веб сајтова које посећујем</translation>
+        <translation>само са веб сајтова које посећујем</translation>
     </message>
     <message>
         <source>Exceptions...</source>
@@ -1532,15 +1581,15 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
     </message>
     <message>
         <source>They expire</source>
-        <translation>Истекну</translation>
+        <translation>истекну</translation>
     </message>
     <message>
         <source>I exit the application</source>
-        <translation>Напустим програм</translation>
+        <translation>напустим програм</translation>
     </message>
     <message>
         <source>At most 90 days</source>
-        <translation>Истекне највише 90 дана</translation>
+        <translation>истекне највише 90 дана</translation>
     </message>
     <message>
         <source>Cookies...</source>
@@ -1580,19 +1629,19 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
     </message>
     <message>
         <source>In a new window</source>
-        <translation>У новом прозору</translation>
+        <translation>у новом прозору</translation>
     </message>
     <message>
         <source>In a new selected tab in the current window</source>
-        <translation>У изабраном новом језичку тренутног прозора</translation>
+        <translation>у изабраном новом језичку тренутног прозора</translation>
     </message>
     <message>
         <source>In a new tab in the current window</source>
-        <translation>У новом језичку тренутног прозора</translation>
+        <translation>у новом језичку тренутног прозора</translation>
     </message>
     <message>
         <source>In the current tab</source>
-        <translation>У тренутном језичку</translation>
+        <translation>у тренутном језичку</translation>
     </message>
     <message>
         <source>Open links from applications:</source>
@@ -1662,6 +1711,58 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
         <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
         <translation>Користи подразумевани мотор претраге као испомоћ уколико је УРЛ задат од стране корисника неисправан</translation>
     </message>
+    <message>
+        <source>Choose Directory...</source>
+        <translation>Изаберите фасциклу...</translation>
+    </message>
+    <message>
+        <source>A cookie session ends:</source>
+        <translation>Колачић сесије истиче:</translation>
+    </message>
+    <message>
+        <source>When I exit the application</source>
+        <translation>кад напустим програм</translation>
+    </message>
+    <message>
+        <source>1 day</source>
+        <translation>за 1 дан</translation>
+    </message>
+    <message>
+        <source>2 days</source>
+        <translation>за 2 дана</translation>
+    </message>
+    <message>
+        <source>3 days</source>
+        <translation>за 3 дана</translation>
+    </message>
+    <message>
+        <source>7 days</source>
+        <translation>за 7 дана</translation>
+    </message>
+    <message>
+        <source>30 days</source>
+        <translation>за 30 дана</translation>
+    </message>
+    <message>
+        <source>AutoFill</source>
+        <translation>Смопопуњавање</translation>
+    </message>
+    <message>
+        <source>AutoFill web forms:</source>
+        <translation>Самопопуњавање веб образаца:</translation>
+    </message>
+    <message>
+        <source>User names and passwords</source>
+        <translation>Корисничка имена и лозинке</translation>
+    </message>
+    <message>
+        <source>Edit...</source>
+        <translation>Уреди...</translation>
+    </message>
+    <message>
+        <source>Browse...</source>
+        <translation>Прегледај...</translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
@@ -1673,6 +1774,14 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
         <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
         <translation>Подешавање мрежног кеша је промењено. Да би било узето у обзир прегледач мора бити поново покренут.</translation>
     </message>
+    <message>
+        <source>Choose Directory</source>
+        <translation>Изаберите фасциклу</translation>
+    </message>
+    <message>
+        <source>Choose CSS File</source>
+        <translation>Изаберите ЦСС фајл</translation>
+    </message>
 </context>
 <context>
     <name>SourceViewer</name>
@@ -1688,18 +1797,6 @@ Do you want to ignore these errors?&lt;/qt&gt;</source>
         <source>&amp;Find</source>
         <translation>Нађ&amp;и</translation>
     </message>
-    <message>
-        <source>&amp;View</source>
-        <translation>Прика&amp;з</translation>
-    </message>
-    <message>
-        <source>&amp;Wrap lines</source>
-        <translation>Поравнај &amp;редове</translation>
-    </message>
-    <message>
-        <source>Source of Page </source>
-        <translation type="obsolete">Изворни код странице</translation>
-    </message>
     <message>
         <source>Source of Page %1</source>
         <translation>Изворни код странице %1</translation>
@@ -1825,10 +1922,6 @@ Do you really want to close this page?
         <source>Add &apos;%1&apos;</source>
         <translation>Додај &apos;%1&apos;</translation>
     </message>
-    <message>
-        <source>Configure Search Engines...</source>
-        <translation>Подеси моторе претраге...</translation>
-    </message>
     <message>
         <source>Clear Recent Searches</source>
         <translation>Уклони скорашње претраге</translation>
@@ -1943,6 +2036,10 @@ Do you really want to close this page?
         <source>Type in a name for the engine</source>
         <translation>Унесите назив за мотор</translation>
     </message>
+    <message>
+        <source>Block Image</source>
+        <translation>Блокирај слику</translation>
+    </message>
 </context>
 <context>
     <name>WebViewSearch</name>
