@@ -27,6 +27,9 @@ int main(int argc, char **argv)
 {
     Q_INIT_RESOURCE(htmls);
     Q_INIT_RESOURCE(data);
+#ifdef Q_WS_X11
+    QApplication::setGraphicsSystem(QString::fromLatin1("raster"));
+#endif
     BrowserApplication application(argc, argv);
     if (!application.isRunning())
         return 0;
