@@ -107,7 +107,6 @@ TabWidget::TabWidget(QWidget *parent)
     , m_nextTabAction(0)
     , m_previousTabAction(0)
     , m_recentlyClosedTabsMenu(0)
-    , m_swappedDelayedWidget(false)
     , m_lineEditCompleter(0)
     , m_locationBars(0)
     , m_tabBar(new TabBar(this))
@@ -335,37 +334,12 @@ WebView *TabWidget::webView(int index) const
     QWidget *widget = this->widget(index);
     if (WebViewWithSearch *webViewWithSearch = qobject_cast<WebViewWithSearch*>(widget)) {
         return webViewWithSearch->m_webView;
-    } else if (widget) {
-        // optimization to delay creating the first webview
-        if (count() == 1) {
-            TabWidget *that = const_cast<TabWidget*>(this);
-            that->setUpdatesEnabled(false);
-            LocationBar *currentLocationBar = qobject_cast<LocationBar*>(m_locationBars->widget(0));
-            bool giveBackFocus = currentLocationBar->hasFocus();
-            m_locationBars->removeWidget(currentLocationBar);
-            m_locationBars->addWidget(new QWidget());
-            that->newTab();
-            that->closeTab(0);
-            QWidget *newEmptyLineEdit = m_locationBars->widget(0);
-            m_locationBars->removeWidget(newEmptyLineEdit);
-            newEmptyLineEdit->deleteLater();
-            m_locationBars->addWidget(currentLocationBar);
-            currentLocationBar->setWebView(currentWebView());
-            if (giveBackFocus)
-                currentLocationBar->setFocus();
-            that->setUpdatesEnabled(true);
-            that->m_swappedDelayedWidget = true;
-            return currentWebView();
-        }
     }
     return 0;
 }
 
 WebViewSearch *TabWidget::webViewSearch(int index) const
 {
-    // so the optimization can be performed
-    webView(index);
-
     QWidget *widget = this->widget(index);
     if (WebViewWithSearch *webViewWithSearch = qobject_cast<WebViewWithSearch*>(widget)) {
         return webViewWithSearch->m_webViewSearch;
@@ -418,21 +392,6 @@ WebView *TabWidget::makeNewTab(bool makeCurrent)
     QWidget::setTabOrder(locationBar, qFindChild<ToolbarSearch*>(BrowserMainWindow::parentWindow(this)));
 #endif
 
-    // optimization to delay creating the more expensive WebView, history, etc
-    if (count() == 0) {
-        QWidget *emptyWidget = new QWidget;
-        QPalette p = emptyWidget->palette();
-        p.setColor(QPalette::Window, palette().color(QPalette::Base));
-        emptyWidget->setPalette(p);
-        emptyWidget->setAutoFillBackground(true);
-        disconnect(this, SIGNAL(currentChanged(int)),
-                   this, SLOT(currentChanged(int)));
-        addTab(emptyWidget, tr("Untitled"));
-        connect(this, SIGNAL(currentChanged(int)),
-                this, SLOT(currentChanged(int)));
-        return 0;
-    }
-
     // webview
     WebView *webView = new WebView;
     locationBar->setWebView(webView);
@@ -620,7 +579,7 @@ void TabWidget::closeTab(int index)
 #if QT_VERSION >= 0x040600
         QByteArray tabHistory;
         QDataStream tabHistoryStream(&tabHistory, QIODevice::WriteOnly);
-        tabHistoryStream << tab->history();
+        tabHistoryStream << *tab->history();
         m_recentlyClosedTabsHistory.prepend(tabHistory);
 #else
         m_recentlyClosedTabsHistory.prepend(QByteArray());
@@ -1067,18 +1026,13 @@ QByteArray TabWidget::saveState() const
     QStringList tabs;
     QList<QByteArray> tabsHistory;
     for (int i = 0; i < count(); ++i) {
-        if (!m_swappedDelayedWidget) {
-            tabs.append(QString::null);
-            tabsHistory.append(QByteArray());
-            continue;
-        }
         if (WebView *tab = webView(i)) {
             tabs.append(QString::fromUtf8(tab->url().toEncoded()));
 #if QT_VERSION >= 0x040600
             if (tab->history()->count() != 0) {
                 QByteArray tabHistory;
                 QDataStream tabHistoryStream(&tabHistory, QIODevice::WriteOnly);
-                tabHistoryStream << tab->history();
+                tabHistoryStream << *tab->history();
                 tabsHistory.append(tabHistory);
             } else {
                 tabsHistory << QByteArray();
