@@ -87,7 +87,9 @@
 #include <qwebframe.h>
 
 #if QT_VERSION >= 0x040600 || defined(WEBKIT_TRUNK)
+#if !defined(QTWEBKIT_VERSION) || QTWEBKIT_VERSION < 0x020000
 Q_DECLARE_METATYPE(QWebElement)
+#endif
 #include <qinputdialog.h>
 #include <qlabel.h>
 #include <qmessagebox.h>
@@ -152,6 +154,9 @@ void WebView::loadSettings()
     QSettings settings;
     settings.beginGroup(QLatin1String("WebView"));
     m_enableAccessKeys = settings.value(QLatin1String("enableAccessKeys"), m_enableAccessKeys).toBool();
+
+    if (!m_enableAccessKeys)
+        hideAccessKeys();
 #endif
     m_page->loadSettings();
 }
@@ -699,7 +704,7 @@ void WebView::keyPressEvent(QKeyEvent *event)
             }
             hideAccessKeys();
         } else {
-            QTimer::singleShot(200, this, SLOT(accessKeyShortcut()));
+            QTimer::singleShot(300, this, SLOT(accessKeyShortcut()));
         }
     }
 #endif
